@@ -67,7 +67,7 @@ def _build_fake_example(
 
 
 class ExampleHarvest(object):
-    '''
+    r'''
                   Finding process             Parsing process
     ----------\                      example                 example (parsed)
     | foo     |      a match       (not parsed)         ............ . . .
@@ -117,7 +117,7 @@ class ExampleHarvest(object):
 
     @log_context('byexample.find')
     def get_examples_from_file(self, filepath):
-        f = open(filepath, 'rtU', encoding=self.encoding)
+        f = open(filepath, 'rt', encoding=self.encoding)
 
         with f as f:
             try:
