@@ -133,11 +133,19 @@ class JavascriptInterpreter(ExampleRunner, PexpectMixin):
             'a': [abspath(__file__, 'gadgets', 'byexample-repl.js')]
         }
 
-    def initialize(self, options):
-        shebang, tokens = self.get_default_cmd()
-        shebang = options['shebangs'].get(self.language, shebang)
+    def get_default_version_cmd(self, *args, **kargs):
+        return "%e %p %a", {
+            'e': '/usr/bin/env',
+            'p': 'nodejs',
+            'a': ["--version"]
+        }
 
-        cmd = ShebangTemplate(shebang).quote_and_substitute(tokens)
+    @constant
+    def get_version(self, options):
+        return self._get_version(options)
+
+    def initialize(self, options):
+        cmd = self.build_cmd(options, *self.get_default_cmd())
 
         # run!
         self._spawn_interpreter(cmd, options)
